#### Arctic Version

```
# Arctic version here
```

#### Arctic Store

```
# VersionStore, TickStore, or ChunkStore
```

#### Platform and version

Put here

#### Description of problem and/or code sample that reproduces the issue

Put Here


